<?php

/*
 * DataTables example server-side processing script.
 *
 * Please note that this script is intentionally extremely simple to show how
 * server-side processing can be implemented, and probably shouldn't be used as
 * the basis for a large complex system. It is suitable for simple use cases as
 * for learning.
 *
 * See http://datatables.net/usage/server-side for full details on the server-
 * side processing requirements of DataTables.
 *
 * @license MIT - http://datatables.net/license_mit
 */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Easy set variables
 */

// DB table to use
$table = 'sante';

// Table's primary key
$primaryKey = 'id';

// Array of database columns which should be read and sent back to DataTables.
// The `db` parameter represents the column name in the database, while the `dt`
// parameter represents the DataTables column identifier. In this case simple
// indexes
$columns = array(
    array('db' => 'age_mutuel_ass', 'dt' => 0,
        'formatter' => function ($d, $row) {
            return number_format($d);
        }),
    array('db' => 'code_produit', 'dt' => 1),
    array('db' => 'code_groupe_gestion_cont', 'dt' => 2),
    array('db' => 'n_contrat_collectif', 'dt' => 3),
    array('db' => 'nom_prenom_sous_coll', 'dt' => 4),
    array('db' => 'code_gp_assure', 'dt' => 5),
    array('db' => 'n_contrat_indiv', 'dt' => 6),
    array('db' => 'nom_prenom_sous_indi', 'dt' => 7),
    array('db' => 'n_pers_ass', 'dt' => 8),
    array('db' => 'nom_assure', 'dt' => 9),
    array('db' => 'type_ass', 'dt' => 10),
    array(
        'db' => 'date_naiss_ass',
        'dt' => 11,
        'formatter' => function ($d, $row) {
            return date('jS M y', strtotime($d));
        },
    ),
    array(
        'db' => 'date_debut_effet',
        'dt' => 12,
        'formatter' => function ($d, $row) {
            return date('jS M y', strtotime($d));
        },
    ),
    array(
        'db' => 'date_fin_effet_ass',
        'dt' => 13,
        'formatter' => function ($d, $row) {
            return date('jS M y', strtotime($d));
        },
    ),
    array('db' => 'adresse1', 'dt' => 14),
    array('db' => 'adresse2', 'dt' => 15),
    array('db' => 'adresse4', 'dt' => 16),
    array('db' => 'adresse5', 'dt' => 17),
    array('db' => 'code_postal', 'dt' => 18),
    array('db' => 'insertion', 'dt' => 19,
        'formatter' => function ($d, $row) {
            return date('jS M y', strtotime($d));
        }),
);

// SQL server connection information
require 'getConnexion.php';

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * If you just want to use the basic configuration for DataTables with PHP
 * server-side, there is no need to edit below this line.
 */

require 'ssp.class.php';

echo json_encode(
    SSP::simple($_GET, $sql_details, $table, $primaryKey, $columns)
);
